package com.ruoyi.web.controller.wechat;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.ruoyi.common.constant.Constants;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.core.domain.model.LoginUser;
import com.ruoyi.framework.web.service.SysPermissionService;
import com.ruoyi.framework.web.service.TokenService;
import com.ruoyi.framework.web.service.UserDetailsServiceImpl;
import com.ruoyi.system.service.ISysUserService;
import com.ruoyi.wechat.component.WeChatTokenService;
import com.ruoyi.wechat.domain.WechatUser;
import com.ruoyi.wechat.mapper.WeChatLoginUser;
import com.ruoyi.wechat.pojo.WxMpAuthorizationUrl;
import com.ruoyi.wechat.service.IWeChatBaseService;
import com.ruoyi.wechat.service.IWechatUserService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.core.userdetails.UserDetailsService;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;

/**
 * @author cj
 */
@Api("微信接口")
@RestController
@RequestMapping("/wechat/base")
public class WeChatBaseController {

    @Autowired
    IWeChatBaseService weChatBaseService;

    @Autowired
    IWechatUserService wechatUserService;

    @Autowired
    WeChatTokenService weChatTokenService;
    @Autowired
    UserDetailsServiceImpl userDetailsService;
    @Autowired
    private TokenService tokenService;
    @Autowired
    private ISysUserService userService;
    @Autowired
    private SysPermissionService permissionService;



    /**
     * 前端获取网页认证的链接
     * @param wxMpAuthorizationUrl 参数实体
     * @return 认证授权url
     */
    @PostMapping("/getWebAuthUrl")
    public String getWebAuthUrl(@RequestBody WxMpAuthorizationUrl wxMpAuthorizationUrl) {
        return weChatBaseService.getWebAuthUrl(wxMpAuthorizationUrl);
    }



    /**
     * 微信认证登录，系统中已存在则直接返回。否则入库
     *
     * @param code
     * @return
     */
    @GetMapping("/login")
    @ApiOperation("login")
    AjaxResult login(String code,HttpServletResponse response) {
        //根据 code 获取 openId
//        String openid = weChatBaseService.webLogin(code);
        String openid = "oqGTlwydOH8ZVYlQGddLKD_AFWfY";
        WechatUser user = getUserByOpenid(openid);
        SysUser sysUser = userService.selectUserByOpenid(openid);
        AjaxResult ajax = AjaxResult.success();
        if (sysUser != null) {
            // 生成令牌
//        String token = weChatTokenService.createToken(new WeChatLoginUser(wechatUser,null));
            LoginUser loginUser = new LoginUser(sysUser.getUserId(), sysUser.getDeptId(), sysUser, permissionService.getMenuPermission(sysUser));
            String token = tokenService.createToken(loginUser);
            ajax.put(Constants.LOGIN_USER_KEY, "sysUser");
            ajax.put(Constants.TOKEN, token);
        }else {
            ajax.put(Constants.LOGIN_USER_KEY, "wechatUser");
            ajax.put(Constants.WECHAT, user);
        }
        return ajax;
    }

    /**
     * 根据 code 获取 openid
     * @param code 微信临时 code
     * @return
     */
    @GetMapping("/getOpenid/{code}")
    @ApiOperation("getOpenid")
    AjaxResult getOpenId(@PathVariable String code) {
        return weChatBaseService.webAuth(code);
    }


    /**
     * 返回前端跳转的首页，并在cookie和请求头同中放入token(包含用户请求)
     * @param request
     * @param response
     * @return
     */
    @GetMapping("/redirect/auth")
    @ApiOperation("回调授权接口")
    void redirectAuth(HttpServletRequest request, HttpServletResponse response) throws IOException {
        String code = request.getParameter("code");
        String state = request.getParameter("state");
        System.out.println(code);
        System.out.println(state);
        String id = state.substring(0,18);
        String appId = state.substring(18);
        //根据 code 获取 openId
//        String openid = weChatBaseService.webLogin(code);
        String openid = "1234567";
//        WechatUser wechatUser = getUserByOpenid(openid);
//        response.addHeader("token",weChatTokenService.createToken(new WeChatLoginUser(wechatUser,null)));
        response.sendRedirect("http://wechat.test.nofeel.club?openid=" + openid);
    }

    /**
     * 根据 openid 获取用户信息
     * @param openid 当前公众号对应用户的账号
     * @return 返回值
     */
    private WechatUser getUserByOpenid(String openid){
        WechatUser wechatUser = wechatUserService.selectWechatUserById(openid);
        if (wechatUser == null) {
            //查询用户信息并且入库
            JSONObject jsonObject = weChatBaseService.getUserInfo(openid);
            wechatUser = JSON.toJavaObject(jsonObject,WechatUser.class);
            wechatUserService.insertWechatUser(wechatUser);
        }
        return wechatUser;
    }

}
