package com.ruoyi.business.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.business.domain.BusCombo;
import com.ruoyi.business.service.IBusComboService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 套餐Controller
 * 
 * @author ruoyi
 * @date 2022-09-21
 */
@RestController
@RequestMapping("/business/combo")
public class BusComboController extends BaseController
{
    @Autowired
    private IBusComboService busComboService;

    /**
     * 查询套餐列表
     */
    @PreAuthorize("@ss.hasPermi('business:combo:list')")
    @GetMapping("/list")
    public TableDataInfo list(BusCombo busCombo)
    {
        startPage();
        List<BusCombo> list = busComboService.selectBusComboList(busCombo);
        return getDataTable(list);
    }

    /**
     * 导出套餐列表
     */
    @PreAuthorize("@ss.hasPermi('business:combo:export')")
    @Log(title = "套餐", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BusCombo busCombo)
    {
        List<BusCombo> list = busComboService.selectBusComboList(busCombo);
        ExcelUtil<BusCombo> util = new ExcelUtil<BusCombo>(BusCombo.class);
        util.exportExcel(response, list, "套餐数据");
    }

    /**
     * 获取套餐详细信息
     */
    @PreAuthorize("@ss.hasPermi('business:combo:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return AjaxResult.success(busComboService.selectBusComboById(id));
    }

    /**
     * 新增套餐
     */
    @PreAuthorize("@ss.hasPermi('business:combo:add')")
    @Log(title = "套餐", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BusCombo busCombo)
    {
        return toAjax(busComboService.insertBusCombo(busCombo));
    }

    /**
     * 修改套餐
     */
    @PreAuthorize("@ss.hasPermi('business:combo:edit')")
    @Log(title = "套餐", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BusCombo busCombo)
    {
        return toAjax(busComboService.updateBusCombo(busCombo));
    }

    /**
     * 删除套餐
     */
    @PreAuthorize("@ss.hasPermi('business:combo:remove')")
    @Log(title = "套餐", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(busComboService.deleteBusComboByIds(ids));
    }
}
