package com.ruoyi.business.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.utils.SecurityUtils;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.business.domain.BusComboUser;
import com.ruoyi.business.service.IBusComboUserService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 套餐用户Controller
 *
 * @author ruoyi
 * @date 2022-09-22
 */
@RestController
@RequestMapping("/business/comboUser")
public class BusComboUserController extends BaseController
{
    @Autowired
    private IBusComboUserService busComboUserService;

    /**
     * 查询套餐用户列表
     */
    @PreAuthorize("@ss.hasPermi('business:comboUser:list')")
    @GetMapping("/list")
    public TableDataInfo list(BusComboUser busComboUser)
    {
        startPage();
        List<BusComboUser> list = busComboUserService.selectBusComboUserList(busComboUser);
        return getDataTable(list);
    }

    @GetMapping("/api/list")
    public TableDataInfo apiAllList(BusComboUser busComboUser)
    {
        busComboUser.setUserId(SecurityUtils.getUserId().intValue());
        List<BusComboUser> list = busComboUserService.selectBusComboUserList(busComboUser);
        return getDataTable(list);
    }

    /**
     * 导出套餐用户列表
     */
    @PreAuthorize("@ss.hasPermi('business:comboUser:export')")
    @Log(title = "套餐用户", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BusComboUser busComboUser)
    {
        List<BusComboUser> list = busComboUserService.selectBusComboUserList(busComboUser);
        ExcelUtil<BusComboUser> util = new ExcelUtil<BusComboUser>(BusComboUser.class);
        util.exportExcel(response, list, "套餐用户数据");
    }

    /**
     * 获取套餐用户详细信息
     */
    @PreAuthorize("@ss.hasPermi('business:comboUser:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return AjaxResult.success(busComboUserService.selectBusComboUserById(id));
    }

    /**
     * 新增套餐用户
     */
    @PreAuthorize("@ss.hasPermi('business:comboUser:add')")
    @Log(title = "套餐用户", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BusComboUser busComboUser)
    {
        return toAjax(busComboUserService.insertBusComboUser(busComboUser));
    }

    /**
     * 修改套餐用户
     */
    @PreAuthorize("@ss.hasPermi('business:comboUser:edit')")
    @Log(title = "套餐用户", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BusComboUser busComboUser)
    {
        return toAjax(busComboUserService.updateBusComboUser(busComboUser));
    }

    /**
     * 删除套餐用户
     */
    @PreAuthorize("@ss.hasPermi('business:comboUser:remove')")
    @Log(title = "套餐用户", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(busComboUserService.deleteBusComboUserByIds(ids));
    }
}
