package com.ruoyi.business.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.business.domain.BusComboVouchers;
import com.ruoyi.business.service.IBusComboVouchersService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 套餐项目Controller
 *
 * @author ruoyi
 * @date 2022-09-21
 */
@RestController
@RequestMapping("/business/comboVouchers")
public class BusComboVouchersController extends BaseController
{
    @Autowired
    private IBusComboVouchersService busComboVouchersService;

    /**
     * 查询套餐项目列表
     */
    @PreAuthorize("@ss.hasPermi('business:comboVouchers:list')")
    @GetMapping("/list")
    public TableDataInfo list(BusComboVouchers busComboVouchers)
    {
        startPage();
        List<BusComboVouchers> list = busComboVouchersService.selectBusComboVouchersList(busComboVouchers);
        return getDataTable(list);
    }

    /**
     * 导出套餐项目列表
     */
    @PreAuthorize("@ss.hasPermi('business:comboVouchers:export')")
    @Log(title = "套餐项目", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BusComboVouchers busComboVouchers)
    {
        List<BusComboVouchers> list = busComboVouchersService.selectBusComboVouchersList(busComboVouchers);
        ExcelUtil<BusComboVouchers> util = new ExcelUtil<BusComboVouchers>(BusComboVouchers.class);
        util.exportExcel(response, list, "套餐项目数据");
    }

    /**
     * 获取套餐项目详细信息
     */
    @PreAuthorize("@ss.hasPermi('business:comboVouchers:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return AjaxResult.success(busComboVouchersService.selectBusComboVouchersById(id));
    }

    /**
     * 新增套餐项目
     */
    @PreAuthorize("@ss.hasPermi('business:comboVouchers:add')")
    @Log(title = "套餐项目", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BusComboVouchers busComboVouchers)
    {
        List<BusComboVouchers> list = busComboVouchersService.selectBusComboVouchersList(busComboVouchers);
        if (list.size() > 0){
            return AjaxResult.error("已存在此项目");
        }
        return toAjax(busComboVouchersService.insertBusComboVouchers(busComboVouchers));
    }

    /**
     * 修改套餐项目
     */
    @PreAuthorize("@ss.hasPermi('business:comboVouchers:edit')")
    @Log(title = "套餐项目", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BusComboVouchers busComboVouchers)
    {
        return toAjax(busComboVouchersService.updateBusComboVouchers(busComboVouchers));
    }

    /**
     * 删除套餐项目
     */
    @PreAuthorize("@ss.hasPermi('business:comboVouchers:remove')")
    @Log(title = "套餐项目", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(busComboVouchersService.deleteBusComboVouchersByIds(ids));
    }
}
