package com.ruoyi.business.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.business.domain.BusVouchersRecords;
import com.ruoyi.business.service.IBusVouchersRecordsService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 核销记录Controller
 * 
 * @author ruoyi
 * @date 2022-09-20
 */
@RestController
@RequestMapping("/business/records")
public class BusVouchersRecordsController extends BaseController
{
    @Autowired
    private IBusVouchersRecordsService busVouchersRecordsService;

    /**
     * 查询核销记录列表
     */
    @PreAuthorize("@ss.hasPermi('business:records:list')")
    @GetMapping("/list")
    public TableDataInfo list(BusVouchersRecords busVouchersRecords)
    {
        startPage();
        List<BusVouchersRecords> list = busVouchersRecordsService.selectBusVouchersRecordsList(busVouchersRecords);
        return getDataTable(list);
    }

    /**
     * 导出核销记录列表
     */
    @PreAuthorize("@ss.hasPermi('business:records:export')")
    @Log(title = "核销记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BusVouchersRecords busVouchersRecords)
    {
        List<BusVouchersRecords> list = busVouchersRecordsService.selectBusVouchersRecordsList(busVouchersRecords);
        ExcelUtil<BusVouchersRecords> util = new ExcelUtil<BusVouchersRecords>(BusVouchersRecords.class);
        util.exportExcel(response, list, "核销记录数据");
    }

    /**
     * 获取核销记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('business:records:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return AjaxResult.success(busVouchersRecordsService.selectBusVouchersRecordsById(id));
    }

    /**
     * 新增核销记录
     */
    @PreAuthorize("@ss.hasPermi('business:records:add')")
    @Log(title = "核销记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BusVouchersRecords busVouchersRecords)
    {
        return toAjax(busVouchersRecordsService.insertBusVouchersRecords(busVouchersRecords));
    }

    /**
     * 修改核销记录
     */
    @PreAuthorize("@ss.hasPermi('business:records:edit')")
    @Log(title = "核销记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BusVouchersRecords busVouchersRecords)
    {
        return toAjax(busVouchersRecordsService.updateBusVouchersRecords(busVouchersRecords));
    }

    /**
     * 删除核销记录
     */
    @PreAuthorize("@ss.hasPermi('business:records:remove')")
    @Log(title = "核销记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(busVouchersRecordsService.deleteBusVouchersRecordsByIds(ids));
    }
}
