package com.ruoyi.business.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.core.domain.entity.SysRole;
import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.system.service.ISysUserService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.business.domain.BusVouchersUser;
import com.ruoyi.business.service.IBusVouchersUserService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 消费券用户关系Controller
 *
 * @author ruoyi
 * @date 2022-09-20
 */
@RestController
@RequestMapping("/business/busVouchersUser")
public class BusVouchersUserController extends BaseController
{
    @Autowired
    private IBusVouchersUserService busVouchersUserService;
    @Autowired
    private ISysUserService sysUserService;

    /**
     * 查询消费券用户关系列表
     */
    @PreAuthorize("@ss.hasPermi('business:busVouchersUser:list')")
    @GetMapping("/list")
    public TableDataInfo list(BusVouchersUser busVouchersUser)
    {
        startPage();
        List<BusVouchersUser> list = busVouchersUserService.selectBusVouchersUserList(busVouchersUser);
        return getDataTable(list);
    }

    @GetMapping("/api/vouchersList")
    public TableDataInfo apiAllList(BusVouchersUser busVouchersUser)
    {
        busVouchersUser.setUserId(SecurityUtils.getUserId().intValue());
        List<BusVouchersUser> list = busVouchersUserService.selectBusVouchersUserList(busVouchersUser);
        return getDataTable(list);
    }
    @GetMapping(value = "/api/{id}")
    public AjaxResult getApiInfo(@PathVariable("id") Integer id)
    {
        BusVouchersUser busVouchersUser = busVouchersUserService.selectBusVouchersUserById(id);
        if (busVouchersUser.getUserId() != SecurityUtils.getUserId().intValue()){
            AjaxResult.success();
        }
        return AjaxResult.success(busVouchersUser);
    }
    @GetMapping(value = "/api/checkAdmin")
    public AjaxResult checkAdmin()
    {
        SysUser sysUser = sysUserService.selectUserById(SecurityUtils.getUserId());
        boolean admin = sysUser.getRoles().stream().allMatch(sysRole -> "volkswagenAdmin".equals(sysRole.getRoleKey()));
        if (admin){
            return AjaxResult.success();
        }
        return AjaxResult.error("请使用管理员账号操作！");
    }

    /**
     * 导出消费券用户关系列表
     */
    @PreAuthorize("@ss.hasPermi('business:busVouchersUser:export')")
    @Log(title = "消费券用户关系", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BusVouchersUser busVouchersUser)
    {
        List<BusVouchersUser> list = busVouchersUserService.selectBusVouchersUserList(busVouchersUser);
        ExcelUtil<BusVouchersUser> util = new ExcelUtil<BusVouchersUser>(BusVouchersUser.class);
        util.exportExcel(response, list, "消费券用户关系数据");
    }

    /**
     * 获取消费券用户关系详细信息
     */
    @PreAuthorize("@ss.hasPermi('business:busVouchersUser:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return AjaxResult.success(busVouchersUserService.selectBusVouchersUserById(id));
    }

    /**
     * 新增消费券用户关系
     */
    @PreAuthorize("@ss.hasPermi('business:busVouchersUser:add')")
    @Log(title = "消费券用户关系", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BusVouchersUser busVouchersUser)
    {
        BusVouchersUser tmp =  new BusVouchersUser();
        tmp.setUserId(busVouchersUser.getUserId());
        tmp.setCode(busVouchersUser.getCode());
        tmp.setProjectType(busVouchersUser.getProjectType());
        List<BusVouchersUser> list = busVouchersUserService.selectBusVouchersUserList(busVouchersUser);
        if (list.size() > 0){
            return AjaxResult.error("已存在此项目");
        }

        return toAjax(busVouchersUserService.insertBusVouchersUser(busVouchersUser));
    }

    /**
     * 修改消费券用户关系
     */
    @PreAuthorize("@ss.hasPermi('business:busVouchersUser:edit')")
    @Log(title = "消费券用户关系", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BusVouchersUser busVouchersUser)
    {
        return toAjax(busVouchersUserService.updateBusVouchersUser(busVouchersUser));
    }

    /**
     * 删除消费券用户关系
     */
    @PreAuthorize("@ss.hasPermi('business:busVouchersUser:remove')")
    @Log(title = "消费券用户关系", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(busVouchersUserService.deleteBusVouchersUserByIds(ids));
    }
}
