package com.ruoyi.business.service.impl;

import java.util.Date;
import java.util.List;
import java.util.stream.Collectors;

import com.ruoyi.business.domain.*;
import com.ruoyi.business.mapper.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.business.service.IBusComboUserService;

/**
 * 套餐用户Service业务层处理
 *
 * @author ruoyi
 * @date 2022-09-22
 */
@Service
public class BusComboUserServiceImpl implements IBusComboUserService {
    @Autowired
    private BusComboUserMapper busComboUserMapper;
    @Autowired
    private BusComboVouchersMapper busComboVouchersMapper;
    @Autowired
    private BusComboMapper busComboMapper;
    @Autowired
    private BusVouchersMapper busVouchersMapper;
    @Autowired
    private BusVouchersUserMapper busVouchersUserMapper;

    /**
     * 查询套餐用户
     *
     * @param id 套餐用户主键
     * @return 套餐用户
     */
    @Override
    public BusComboUser selectBusComboUserById(Integer id) {
        return busComboUserMapper.selectBusComboUserById(id);
    }

    /**
     * 查询套餐用户列表
     *
     * @param busComboUser 套餐用户
     * @return 套餐用户
     */
    @Override
    public List<BusComboUser> selectBusComboUserList(BusComboUser busComboUser) {
        return busComboUserMapper.selectBusComboUserList(busComboUser);
    }

    /**
     * 新增套餐用户
     *
     * @param busComboUser 套餐用户
     * @return 结果
     */
    @Override
    public int insertBusComboUser(BusComboUser busComboUser) {
        BusComboVouchers busComboVouchers = new BusComboVouchers();
        busComboVouchers.setComboId(busComboUser.getComboId());
        List<BusComboVouchers> list = busComboVouchersMapper.selectBusComboVouchersList(busComboVouchers);
        for (BusComboVouchers tmp : list) {
            BusVouchers busVouchers = busVouchersMapper.selectBusVouchersByCode(tmp.getCode());
            BusVouchersUser busVouchersUser = new BusVouchersUser();
            busVouchersUser.setComboId(tmp.getComboId());
            busVouchersUser.setCode(tmp.getCode());
//            套餐项目
            busVouchersUser.setProjectType("1");
            busVouchersUser.setUserId(busComboUser.getUserId());
            busVouchersUser.setStartDate(new Date());
            busVouchersUser.setValidityDate(new Date());
            busVouchersUser.setCount(busVouchers.getUserCount());
            busVouchersUser.setConsumeCount(0);
            busVouchersUserMapper.insertBusVouchersUser(busVouchersUser);
        }
        return busComboUserMapper.insertBusComboUser(busComboUser);
    }

    /**
     * 修改套餐用户
     *
     * @param busComboUser 套餐用户
     * @return 结果
     */
    @Override
    public int updateBusComboUser(BusComboUser busComboUser) {
        BusComboVouchers busComboVouchers = new BusComboVouchers();
        busComboVouchers.setComboId(busComboUser.getComboId());
        List<BusComboVouchers> list = busComboVouchersMapper.selectBusComboVouchersList(busComboVouchers);

        BusVouchersUser tmpV = new BusVouchersUser();
        tmpV.setComboId(busComboUser.getComboId());
        tmpV.setUserId(busComboUser.getUserId());
        List<BusVouchersUser> listV = busVouchersUserMapper.selectBusVouchersUserList(tmpV);

        for (BusComboVouchers tmp : list) {
            List<BusVouchersUser> tmpList = listV.stream().filter(vouchers -> vouchers.getCode().equals(tmp.getCode())).collect(Collectors.toList());
            if (tmpList.size() == 0){
//                修改，套餐内没有的补充
                BusVouchers busVouchers = busVouchersMapper.selectBusVouchersByCode(tmp.getCode());
                BusVouchersUser busVouchersUser = new BusVouchersUser();
                busVouchersUser.setComboId(tmp.getComboId());
                busVouchersUser.setCode(tmp.getCode());
//            套餐项目
                busVouchersUser.setProjectType("1");
                busVouchersUser.setUserId(busComboUser.getUserId());
                busVouchersUser.setStartDate(new Date());
                busVouchersUser.setValidityDate(new Date());
                busVouchersUser.setCount(busVouchers.getUserCount());
                busVouchersUser.setConsumeCount(0);
                busVouchersUserMapper.insertBusVouchersUser(busVouchersUser);
            }
        }
        return busComboUserMapper.updateBusComboUser(busComboUser);
    }

    /**
     * 批量删除套餐用户
     *
     * @param ids 需要删除的套餐用户主键
     * @return 结果
     */
    @Override
    public int deleteBusComboUserByIds(Integer[] ids) {
        return busComboUserMapper.deleteBusComboUserByIds(ids);
    }

    /**
     * 删除套餐用户信息
     *
     * @param id 套餐用户主键
     * @return 结果
     */
    @Override
    public int deleteBusComboUserById(Integer id) {
        return busComboUserMapper.deleteBusComboUserById(id);
    }
}
